@@ -18,7 +18,7 @@ NOTED_SENSE1_FILE_DIR="src/noted/sense-o/sense-provision.sh"
 NOTED_SENSE2_FILE_DIR="src/noted/sense-o/sense-cancel.sh"
 NOTED_SENSE3_FILE_DIR="src/noted/sense-o/sense_util.py"
 
-function create_folders(){
+create_folders(){
     echo "Creating folders for NOTED."
     mkdir -p $MAIN_DIR
     mkdir -p $LOGS_DIR
@@ -28,7 +28,7 @@ function create_folders(){
     mkdir -p $TRANSFERS_DIR
 }
 
-function copy_config_files(){
+copy_config_files(){
     echo "Copying configuration files for NOTED."
     cp $NOTED_CONFIG_FILE_DIR $CONFIG_DIR
     cp $NOTED_SENSE1_FILE_DIR $SENSE_DIR
